function plot_ElementaryTags(Gh)
  assert( ~Gh.partitionnedfile ,' Not yet implemented for partionned files ' )
  
  [Soft,Release]=fc_tools.sys.getSoftware();
  LegendOptions={'Location','NorthEastOutside','AutoUpdate','off'};
  if strcmp(lower(Soft),'octave') &&  ( fc_tools.utils.strversion2num(Release) <=  fc_tools.utils.strversion2num('4.2.1') )
    LegendOptions={'Location','NorthEastOutside'};
  elseif strcmp(lower(Soft),'matlab') &&  verLessThan('matlab','R2016b')
    LegendOptions={'Location','NorthEastOutside'};
  end
  
  type=1; % line
  elt1=fc_oogmsh.gmsh.elm_type_desc(type);
  
  eltags1=Gh.get_ElementaryTags(type);q1={};me1={};
  n1=length(eltags1);
  fprintf('  %s :\n',elt1.desc)
  k=1;
  for i=1:n1
    [Q,ME]=Gh.get_localmesh_ElementaryTag(type,eltags1(i));
    if ~isempty(ME)
      q1{k}=Q;me1{k}=ME;
      fprintf('     elementary_tag=%7d, nq=%7d, nme=%7d\n',eltags1(i),size(q1{k},2),size(me1{k},2))
      k=k+1;
    else
      fprintf('     elementary_tag=%7d, nq=%7d, nme=%7d -> DELETED\n',eltags1(i),size(Q,2),size(ME,2))
    end
  end

  type=2; % triangle
  elt2=fc_oogmsh.gmsh.elm_type_desc(type);
  
  eltags2=Gh.get_ElementaryTags(type);q2={};me2={};
  n2=length(eltags2);
  fprintf('  %s :\n',elt2.desc)
  k=1;
  for i=1:n2
    [Q,ME]=Gh.get_localmesh_ElementaryTag(type,eltags2(i));
    if ~isempty(ME)
      q2{k}=Q;me2{k}=ME;
      fprintf('     elementary_tag=%7d, nq=%7d, nme=%7d\n',eltags2(i),size(q2{k},2),size(me2{k},2))
      k=k+1;
    else
      fprintf('     elementary_tag=%7d, nq=%7d, nme=%7d -> DELETED\n',eltags2(i),size(Q,2),size(ME,2))
    end
  end

  if Gh.dim==3
    type=4; % tetrahedron
    elt3=fc_oogmsh.gmsh.elm_type_desc(type);
    
    eltags3=Gh.get_ElementaryTags(type);q3={};me3={};
    n3=length(eltags3);
    fprintf('  %s :\n',elt3.desc)
    k=1;
    for i=1:n3
      [Q,ME]=Gh.get_localmesh_ElementaryTag(type,eltags3(i));
      if ~isempty(ME) 
        q3{k}=Q;me3{k}=ME;
        fprintf('     elementary_tag=%7d, nq=%7d, nme=%7d\n',eltags3(i),size(q3{k},2),size(me3{k},2))
        k=k+1;
      else
        fprintf('     elementary_tag=%7d, nq=%7d, nme=%7d -> DELETED\n',eltags3(i),size(Q,2),size(ME,2))
      end
    end
    n3=length(q3);
  else
    n3=0;
  end

  if n1>0
    figure()
    colors = fc_tools.graphics.selectColors(n1);
    hold on
    labname=fc_oogmsh.funLabName(Gh.dim,1);
    for i=1:n1
      h1(i)=fc_graphics4mesh.plotmesh(q1{i},me1{i},'color',colors(i,:));
      clegend1{i}=labname(eltags1(i));
    end
    if Gh.dim==3,view(3);end
    legend(h1,clegend1,LegendOptions{:});
    axis image
    title(sprintf('Elementary Tags for %s',elt1.desc))
  end
  
  if n2>0
    figure()
    colors = fc_tools.graphics.selectColors(n2);
    hold on
    labname=fc_oogmsh.funLabName(Gh.dim,2);
    for i=1:n2
      h2(i)=fc_graphics4mesh.plotmesh(q2{i},me2{i},'color',colors(i,:));
      clegend2{i}=labname(eltags2(i));
    end
    if Gh.dim==3,view(3);end
    legend(h2,clegend2,LegendOptions{:}); 
    axis image
    title(sprintf('Elementary Tags for %s',elt2.desc))
  end
  
  if n3>0
    figure()
    colors = fc_tools.graphics.selectColors(n3);
    hold on
    labname=fc_oogmsh.funLabName(Gh.dim,3);
    for i=1:n3
      h3(i)=fc_graphics4mesh.plotmesh(q3{i},me3{i},'color',colors(i,:));
      clegend3{i}=labname(eltags3(i));
    end
    view(3)
    legend(h3,clegend3,LegendOptions{:}); 
    axis image
    title(sprintf('Elementary Tags for %s',elt3.desc))
  end
 end 
